{% load i18n pages_tags %}

{% if on_home %}
<li>{% trans "Home" %}</li>
{% else %}
{% for page in page_branch %}

    {% if not has_home and page.is_primary and forloop.first %}
    <li id="breadcrumb-menu-home">
        <a href="{% url "home" %}">{% trans "Home" %}</a>
    </li>
    {% endif %}

    {% if page.is_current_or_ascendant %}
    {% if page.is_current %}
    <li id="breadcrumb-menu-{{ page.html_id }}"
        class="active">{{ page.title }}</li>
    {% else %}
    <li id="breadcrumb-menu-{{ page.html_id }}">
        {% if page.menuplaceholder %}<a class="breadcrumbnomenu">{{ page.title }}</a>{% else %}
        <a href="{{ page.get_absolute_url }}">{{ page.title }}</a>
        {% endif %}
    </li>
    {% endif %}
    {% if page.has_children %}{% page_menu page %}{% endif %}
    {% endif %}

{% endfor %}
{% endif %}
