{% load i18n pages_tags %}

{% spaceless %}
{% if page_branch_in_menu %}

{% for page in page_branch %}
    {% if page.is_primary %}
        {% if forloop.first %}
            <div class="nav-footer">
        {% endif %}
        {% if page.in_menu %}
            <ul class="list-unstyled">
        {% endif %}
    {% endif %}

    {% if page.in_menu %}
        {% if forloop.first and not page.parent.in_menu and not page.is_primary %}
            <ul class="list-unstyled">
        {% endif %}
        <li {% if page.is_current_or_ascendant %}class="active"{% endif %}
            id="footer-menu-{{ page.html_id }}">
            {% if page.menuplaceholder %}<a class="footernomenu">{{ page.title }}</a>{% else %}
            <a href="{{ page.get_absolute_url }}">{{ page.title }}</a>
            {% endif %}</li>
    {% endif %}

    {% if page.in_menu and page.has_children_in_menu %}{% page_menu page %}{% endif %}

    {% if page.in_menu %}
        {% if forloop.first and not page.parent.in_menu and not page.is_primary %}
            </li></ul>
        {% endif %}
    {% endif %}

    {% if page.is_primary %}
        {% if page.in_menu %}
            </ul>
        {% endif %}
        {% if forloop.last %}
            </div>
        {% endif %}
    {% endif %}

{% endfor %}

{% endif %}
{% endspaceless %}
